Learn R Programming

DiscriMiner (version 0.1-22)

bordeaux: Bordeaux Wines Dataset

Description

Quality measures of wines from Bordeaux, France

Usage

data(bordeaux)

Arguments

format

A data frame with 34 observations on the following 6 variables. ll{ year year of harvest temperature sum of daily average temperatures (in celsius degrees) sun duration of insolation (in hours) heat number of super-hot days rain rain level (in millimeters) quality wine quality: a factor with levels bad, good, and medium }

References

Chapter 10: Analyse Discriminante, page 353. Tenenhaus M. (2007) Statistique. Dunod, Paris.

Examples

Run this code
# load data
  data(bordeaux)
  
  # structure of data
  str(bordeaux)

Run the code above in your browser using DataLab