Learn R Programming

DiscriMiner (version 0.1-28)

insurance: Insurance Dataset

Description

Dataset of car-insurance customers from Belgium in 1992

Arguments

format

A data frame with 1106 observations on the following 10 variables. ll{ Claims Group variable. A factor with levels bad and good Use Type of Use. A factor with levels private and professional Type Insurance Type. A factor with levels companies, female, and male Language Language. A factor with levels flemish and french BirthCohort Birth Cohort. A factor with levels BD_1890_1949, BD_1950_1973, and BD_unknown Region Geographic Region. A factor with levels Brussels and Other_regions BonusMalus Level of bonus-malus. A factor with levels BM_minus and BM_plus YearSuscrip Year of Subscription. A factor with levels YS<86< code=""> and YS>=86 Horsepower Horsepower. A factor with levels HP<=39< code=""> and HP>=40 YearConstruc Year of vehicle construction. A factor with levels YC_33_89 and YC_90_91 }

Details

Dataset for DISQUAL method

References

Saporta G., Niang N. (2006) Correspondence Analysis and Classification. In Multiple Correspondence Analysis and Related Methods, M. Greenacre and J. Blasius, Eds., pp 371-392. Chapman & Hall/CRC, Boca Raton, Florida, USA.

See Also

disqual

Examples

Run this code
# load data
  data(insurance)

  # structure
  str(insurance)

Run the code above in your browser using DataLab